========
bios_pnp
========

Very simple module that enumerates Legacy Plug and Play devices.

Currently only Linux is supported. The data is sourced from the sysfs
file system.

Example::

  TODO


License
=======

Apache 2.0
